import os
import time
from pathlib import Path

def launch_programs(filename):
    """Launches programs from a text file.

    Args:
        filename: The path to the text file.

    Returns:
        None.
    """

    # Check if the file exists.
    if not os.path.isfile(filename):
        print(f"Error: File '{filename}' not found.")
        desktop_path = Path.home() / "Desktop" / filename
        print(f"The file is supposed to be in the following directory: {desktop_path}")
        input("Press any key to continue...")
        return

    # Read the programs to launch from the file.
    with open(filename, 'r') as file:
        programs = file.read().splitlines()

    # Launch each program with a delay of 7 seconds.
    for program in programs:
        try:
            os.startfile(program)
            time.sleep(10)  # Add a 10-second delay
        except FileNotFoundError:
            print(f"Error: Could not find program '{program}'.")

if __name__ == "__main__":
    filename = "launchprofile.txt"
    desktop_path = Path.home() / "Desktop" / filename
    launch_programs(desktop_path)

